<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="82"/>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>MX Cleanup</source>
        <translation>MX Cleanup</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="137"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>Apply</source>
        <translation>Aplica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Main</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="542"/>
        <source>Empty Trash</source>
        <translation>Buida la Paperera </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="551"/>
        <source>Trash older than:</source>
        <translation>Esborra els més antics de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="704"/>
        <source>Don&apos;t empty</source>
        <translation>No ho buidis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="297"/>
        <location filename="../mainwindow.ui" line="447"/>
        <location filename="../mainwindow.ui" line="574"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <source> days</source>
        <translation>dies</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="593"/>
        <source>All users</source>
        <translation>Tots els usuaris</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="612"/>
        <source>Selected user</source>
        <translation>Usuari seleccionat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="660"/>
        <source>Clear APT Cache</source>
        <translation>Buida la memòria cau de l&apos;APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Old files</source>
        <translation>Fitxers antics</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="694"/>
        <source>All files</source>
        <translation>Tots els fitxers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="834"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Eina gràfica per analitzar l&apos;ús del disc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="849"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Executa l&apos;analitzador de l&apos;ús del disc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>Schedule</source>
        <translation>Planificació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="485"/>
        <source>No automatic clean</source>
        <translation>Sense neteja automàtica</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="492"/>
        <source>At reboot</source>
        <translation>En reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Daily</source>
        <translation>Diari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="506"/>
        <source>Weekly</source>
        <translation>Setmanal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="513"/>
        <source>Monthly</source>
        <translation>Mensual</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Free Disk Space for User</source>
        <translation>Espai de disc lliure per l&apos;usuari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="751"/>
        <location filename="../mainwindow.ui" line="767"/>
        <source>Select user to repair</source>
        <translation>Trieu l&apos;usuari a reparar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Select user:</source>
        <translation>Trieu l&apos;usuari: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Delete Logs</source>
        <translation>Esborra els Registres</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <source>All logs</source>
        <translation>Tots els registres</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Old logs</source>
        <translation>Registres antics</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>Logs older than:</source>
        <translation>Registres més antics de:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="784"/>
        <source>Removal tool</source>
        <translation>Eina d&apos;eliminació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="793"/>
        <source>Remove unused WiFi drivers</source>
        <translation>Elimina els controladors de WiFi que no s&apos;usen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="812"/>
        <source>List and select kernels to remove</source>
        <translation>Mostra i selecciona kernels a eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="345"/>
        <source>Clean Flatpak</source>
        <translation>Neteja Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <source>Remove unused runtimes</source>
        <translation>Elimina els executables sense ús</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>Clean Folders</source>
        <translation>Neteja carpetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="437"/>
        <source>Not accessed for:</source>
        <translation>No accedit per:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Cache</source>
        <translation>Memòria cau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>All (potentially dangerous)</source>
        <translation>Tots (potencialment perillós)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Thumbnails</source>
        <translation>Miniatures</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="215"/>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>Press any key to close</source>
        <translation>Premeu qualsevol tecla per tancar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source> day</source>
        <translation>dia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Error</source>
        <translation type="unfinished">Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Failed to elevate privileges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="529"/>
        <source>Done</source>
        <translation>Fet </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>Cleanup script will run at reboot</source>
        <translation>L&apos;script Cleanup s&apos;executarà en reiniciar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Cleanup command done</source>
        <translation>Feta l&apos;ordre de neteja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>%1 MiB were freed</source>
        <translation>S&apos;ha alliberat %1 MiB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>About</source>
        <translation>Quant a </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>Quick and safe removal of old files</source>
        <translation>Eliminació ràpida i segura de fitxers antics</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Kernel actualment en ús: &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="638"/>
        <source>Remove selected</source>
        <translation>Elimina els seleccionats</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>Similar kernels that can be removed:</source>
        <translation>Es poden eliminar kernels semblants</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>Other kernels that can be removed:</source>
        <translation>Altres kernels que es poden eliminar: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation>&lt;b&gt;Res a eliminar.&lt;/b&gt; No es pot eliminar el kernel en ús.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="71"/>
        <location filename="../about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Quick safe removal of old files</source>
        <translation>Eliminació ràpida i segura de fitxers vells</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <location filename="../main.cpp" line="87"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembla que esteu connectat com a administrador, si us plau sortiu i connecteu-vos com a usuari normal per a usar aquest programa.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You must run this program with admin access.</source>
        <translation>Cal executar aquest programa com a administrador.</translation>
    </message>
</context>
</TS>
